@@ -1,6 +1,11 @@
 package Reddit::Client;
 
-our $VERSION = '1.0972';  
+our $VERSION = '1.098';  
+# 1.098:
+# print_response - for debugging, will print Reddit's actual response
+# submit_link and submit_text can now accept 'sub' as well as 'subreddit'
+# and get_subreddit_comments too
+# remove function in main, Link, and Comment
 
 $VERSION = eval $VERSION;
 
@@ -101,6 +106,7 @@ use constant API_SUBREDDIT_INFO      => 30;
 use constant API_SEARCH              => 31;
 use constant API_MODQ                => 32;
 use constant API_EDIT                => 33;
+use constant API_REMOVE              => 34;
 
 #===============================================================================
 # Parameters
@@ -148,6 +154,7 @@ $API[API_SUBREDDIT_INFO] = ['GET',  '/r/%s/about'             ];
 $API[API_SEARCH        ] = ['GET',  '/r/%s/search'            ];
 $API[API_MODQ          ] = ['GET',  '/r/%s/about/%s'          ];
 $API[API_EDIT          ] = ['POST', '/api/editusertext'       ];
+$API[API_REMOVE        ] = ['POST', '/api/remove'             ];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -196,6 +203,7 @@ use fields (
 	'username',
 	'password',
 	'request_errors',
+	'print_response',
 );
 
 sub new {
@@ -206,8 +214,9 @@ sub new {
 		carp "Reddit::Client->new: user_agent required in future version.";
 		$param{user_agent} = $UA;
 	}
-	$self->{user_agent} = $param{user_agent};
-	$self->{request_errors}= $param{request_errors} || 0;
+	$self->{user_agent} 	= $param{user_agent};
+	$self->{request_errors} = $param{request_errors} || 0;
+	$self->{print_response} = $param{print_response} || 0;
 
 	if ($param{username} || $param{password} || $param{client_id} || $param{secret}) {
 		if (!$param{username} || !$param{password} || !$param{client_id} || !$param{secret}) {
@@ -222,7 +231,6 @@ sub new {
 		}
 	}
 
-	#print Dumper $self;
     return $self;
 }
 
@@ -257,6 +265,7 @@ sub request {
 	token	   => $self->{token},
 	tokentype  => $self->{tokentype},
 	request_errors=> $self->{request_errors},
+	print_response=> $self->{print_response},
     );
 
     return $request->send;
@@ -564,33 +573,6 @@ sub find_subreddits {
     	];
 }
 
-# reports spam modqueue unmoderated edited
-sub get_modlinks {
-    	my ($self, %param) = @_;
-
-	my $query = $self->set_listing_defaults(%param);
-	my $sub   = $param{sub} || $param{subreddit} || 'mod';
-	my $mode  = $param{mode} || 'modqueue';
-
-    	my $result = $self->api_json_request(
-		api  => API_MODQ, 
-		args => [$sub, $mode],
-		data => $query,
-	);
-
-	#return $result->{data};
-
-	return [
-		map {
-
-		$_->{kind} eq "t1" ? 
-			Reddit::Client::Comment->new($self, $_->{data}) :
-			Reddit::Client::Link->new($self, $_->{data})
-		} 
-
-		@{$result->{data}{children}} 
-	];
-}
 sub fetch_links {
     	my ($self, %param) = @_;
     	my $subreddit = $param{sub} || $param{subreddit} || '';
@@ -643,7 +625,7 @@ sub get_comment {
 
 sub get_subreddit_comments {
 	my ($self, %param) = @_;
-	my $subreddit 	= $param{subreddit} 	|| '';
+	my $subreddit 	= $param{sub} || $param{subreddit} || '';
 	my $view 	= $param{view} 		|| VIEW_DEFAULT;
 
 	my $query = {};
@@ -667,6 +649,47 @@ sub get_subreddit_comments {
     	];
 }
 
+#=============================================================
+# Moderation
+#=============================================================
+sub remove {
+	my $self = shift;
+	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	
+    	my $result = $self->api_json_request(
+		api  => API_REMOVE,
+		data => { id => $fullname },
+	);
+	return $result;
+}
+# reports spam modqueue unmoderated edited
+sub get_modlinks {
+    	my ($self, %param) = @_;
+
+	my $query = $self->set_listing_defaults(%param);
+	my $sub   = $param{sub} || $param{subreddit} || 'mod';
+	my $mode  = $param{mode} || 'modqueue';
+
+    	my $result = $self->api_json_request(
+		api  => API_MODQ, 
+		args => [$sub, $mode],
+		data => $query,
+	);
+
+	#return $result->{data};
+
+	return [
+		map {
+
+		$_->{kind} eq "t1" ? 
+			Reddit::Client::Comment->new($self, $_->{data}) :
+			Reddit::Client::Link->new($self, $_->{data})
+		} 
+
+		@{$result->{data}{children}} 
+	];
+}
+
 # Get information about a user
 sub get_user {
     	my ($self, %param) = @_;
@@ -752,7 +775,7 @@ sub delete {
 
 sub submit_link {
     my ($self, %param) = @_;
-    my $subreddit = $param{subreddit} || '';
+    my $subreddit = $param{subreddit} || $param{sub} || '';
     my $title     = $param{title}     || croak 'Expected "title"';
     my $url       = $param{url}       || croak 'Expected "url"';
     my $replies = exists $param{inbox_replies} ? ($param{inbox_replies} ? "true" : "false") : "true";
@@ -776,7 +799,7 @@ sub submit_link {
 
 sub submit_text {
     my ($self, %param) = @_;
-    my $subreddit = $param{subreddit} || '';
+    my $subreddit = $param{subreddit} || $param{sub} || '';
     my $title     = $param{title}     || croak 'Expected "title"';
     my $text      = $param{text}      || croak 'Expected "text"';
     # true and false have to be the strings "true" or "false"
@@ -1142,7 +1165,7 @@ __END__
 
 Reddit::Client - A Perl wrapper for the Reddit API.
 
-Up to date, nicely-formatted documentation can be found at L<http://redditclient.readthedocs.org/en/latest/>. 
+Up to date, nicely-formatted documentation can be found at L<http://redditclient.readthedocs.org/en/latest/>.  What follows is probably not incorrect, but is probably not complete or current either.
 
 =head1 SYNOPSIS
 
