@@ -37,7 +37,10 @@ sub reply {
 	return "t1_".$cmtid if $cmtid;
 	return $cmtid;
 }
-
+sub remove {
+	my $self = shift;
+	return $self->{session}->remove($self->{name});
+}
 sub edit {
     	my ($self, $text) = @_;
 	my $cmtid = $self->{session}->edit($self->{name}, $text);
