@@ -23,6 +23,10 @@ sub reply {
 	return "t1_".$cmtid if $cmtid;
 	return $cmtid;
 }
+sub remove {
+	my $self = shift;
+	return $self->{session}->remove($self->{name});
+}
 sub edit {
     	my ($self, $text) = @_;
 	croak 'This is not a self post' unless $self->{is_self};
